=======
icartt
=======

``icartt`` is an ICARTT format reader and writer

Documentation
=============

maintained at https://boxmodeling.meteo.physik.uni-muenchen.de/documentation

Installation
============